@@ -1,7 +1,7 @@
-from typing import Any, Optional, Dict, List
+from typing import Any, Dict, List, Optional
 
 import attr
-from marshmallow import ValidationError, validates_schema, pre_load
+from marshmallow import ValidationError, pre_load, validates_schema
 from marshmallow_annotations.ext.attrs import AttrsSchema
 
 """
@@ -37,8 +37,8 @@ class User:
     role: Optional[str] = None
     dismissed: Optional[List[str]] = None
     has_environment: Optional[bool] = None
+    service_account: Optional[bool] = None
     other_key_values: Optional[Dict[str, str]] = attr.ib(factory=dict)  # type: ignore
-    # TODO: Add frequent_used, bookmarked, & owned resources
 
 
 class UserSchema(AttrsSchema):
@@ -57,32 +57,34 @@ class UserSchema(AttrsSchema):
 
     @pre_load
     def preprocess_data(self, data: Dict[str, Any]) -> Dict[str, Any]:
-        if self._str_no_value(data.get('user_id')):
-            data['user_id'] = data.get('email')
+        if self._str_no_value(data.get("user_id")):
+            data["user_id"] = data.get("email")
 
-        if self._str_no_value(data.get('profile_url')):
-            data['profile_url'] = ''
-            if data.get('GET_PROFILE_URL'):
-                data['profile_url'] = data.get('GET_PROFILE_URL')(data['user_id'])  # type: ignore
+        if self._str_no_value(data.get("profile_url")):
+            data["profile_url"] = ""
+            if data.get("GET_PROFILE_URL"):
+                data["profile_url"] = data.get("GET_PROFILE_URL")(data["user_id"])  # type: ignore
 
-        first_name = data.get('first_name')
-        last_name = data.get('last_name')
+        first_name = data.get("first_name")
+        last_name = data.get("last_name")
 
-        if self._str_no_value(data.get('full_name')) and first_name and last_name:
-            data['full_name'] = f"{first_name} {last_name}"
+        if self._str_no_value(data.get("full_name")) and first_name and last_name:
+            data["full_name"] = f"{first_name} {last_name}"
 
-        if self._str_no_value(data.get('display_name')):
-            if self._str_no_value(data.get('full_name')):
-                data['display_name'] = data.get('email')
+        if self._str_no_value(data.get("display_name")):
+            if self._str_no_value(data.get("full_name")):
+                data["display_name"] = data.get("email")
             else:
-                data['display_name'] = data.get('full_name')
+                data["display_name"] = data.get("full_name")
 
         return data
 
     @validates_schema
     def validate_user(self, data: Dict[str, Any]) -> None:
-        if self._str_no_value(data.get('display_name')):
-            raise ValidationError('"display_name", "full_name", or "email" must be provided')
+        if self._str_no_value(data.get("display_name")):
+            raise ValidationError(
+                '"display_name", "full_name", or "email" must be provided'
+            )
 
-        if self._str_no_value(data.get('user_id')):
+        if self._str_no_value(data.get("user_id")):
             raise ValidationError('"user_id" or "email" must be provided')
